@@ -24,7 +24,7 @@ from oslo_context import context as oslo_context
 from sqlalchemy import Column
 from sqlalchemy import Integer
 from sqlalchemy import MetaData
-from sqlalchemy.orm import mapper
+from sqlalchemy.orm import registry
 from sqlalchemy.orm import Session
 from sqlalchemy import select
 from sqlalchemy import String
@@ -357,11 +357,11 @@ class MockFacadeTest(test_base.BaseTestCase):
         maker_factories = mock.Mock(side_effect=get_maker)
 
         maker_factories(
-            autocommit=True, engine=engines.writer,
+            autocommit=False, engine=engines.writer,
             expire_on_commit=False)
         if self.slave_uri:
             maker_factories(
-                autocommit=True, engine=engines.async_reader,
+                autocommit=False, engine=engines.async_reader,
                 expire_on_commit=False)
 
         yield makers
@@ -1379,6 +1379,19 @@ class PatchFactoryTest(test_base.BaseTestCase):
         self.assertTrue(engine_args['sqlite_fk'])
         self.assertEqual("FOOBAR", engine_args["mysql_sql_mode"])
         self.assertEqual(38, engine_args["max_overflow"])
+        self.assertNotIn("mysql_wsrep_sync_wait", engine_args)
+
+    def test_new_manager_from_options(self):
+        """test enginefacade's defaults given a default structure from opts"""
+
+        factory = enginefacade._TransactionFactory()
+        cfg.CONF.register_opts(options.database_opts, 'database')
+        factory.configure(**dict(cfg.CONF.database.items()))
+        engine_args = factory._engine_args_for_conf(None)
+
+        self.assertEqual(None, engine_args["mysql_wsrep_sync_wait"])
+        self.assertEqual(True, engine_args["sqlite_synchronous"])
+        self.assertEqual("TRADITIONAL", engine_args["mysql_sql_mode"])
 
 
 class SynchronousReaderWSlaveMockFacadeTest(MockFacadeTest):
@@ -1671,11 +1684,13 @@ class LiveFacadeTest(db_test_base._DbTestCase):
         metadata.create_all(self.engine)
         self.addCleanup(metadata.drop_all, self.engine)
 
+        reg = registry()
+
         class User(object):
             def __init__(self, name):
                 self.name = name
 
-        mapper(User, user_table)
+        reg.map_imperatively(User, user_table)
         self.User = User
 
     def _assert_ctx_connection(self, context, connection):
@@ -1690,11 +1705,12 @@ class LiveFacadeTest(db_test_base._DbTestCase):
         with enginefacade.writer.using(context) as session:
             session.add(self.User(name="u1"))
 
-        session = self.sessionmaker(autocommit=True)
-        self.assertEqual(
-            "u1",
-            session.query(self.User.name).scalar()
-        )
+        session = self.sessionmaker(autocommit=False)
+        with session.begin():
+            self.assertEqual(
+                "u1",
+                session.query(self.User.name).scalar()
+            )
 
     def test_transaction_rollback(self):
         context = oslo_context.RequestContext()
@@ -1710,11 +1726,12 @@ class LiveFacadeTest(db_test_base._DbTestCase):
 
         self.assertRaises(MyException, go, context)
 
-        session = self.sessionmaker(autocommit=True)
-        self.assertEqual(
-            None,
-            session.query(self.User.name).scalar()
-        )
+        session = self.sessionmaker(autocommit=False)
+        with session.begin():
+            self.assertEqual(
+                None,
+                session.query(self.User.name).scalar()
+            )
 
     @mock.patch.object(Session, 'commit')
     @mock.patch.object(Session, 'rollback')
@@ -1781,11 +1798,12 @@ class LiveFacadeTest(db_test_base._DbTestCase):
                 s2.add(self.User(name="u1"))
                 s2.flush()
 
-        session = self.sessionmaker(autocommit=True)
-        self.assertEqual(
-            "u1",
-            session.query(self.User.name).scalar()
-        )
+        session = self.sessionmaker(autocommit=False)
+        with session.begin():
+            self.assertEqual(
+                "u1",
+                session.query(self.User.name).scalar()
+            )
 
     def test_context_deepcopy_on_connection(self):
         context = oslo_context.RequestContext()
@@ -1802,11 +1820,12 @@ class LiveFacadeTest(db_test_base._DbTestCase):
 
             self._assert_ctx_connection(ctx2, conn2)
 
-        session = self.sessionmaker(autocommit=True)
-        self.assertEqual(
-            "u1",
-            session.query(self.User.name).scalar()
-        )
+        session = self.sessionmaker(autocommit=False)
+        with session.begin():
+            self.assertEqual(
+                "u1",
+                session.query(self.User.name).scalar()
+            )
 
     @db_test_base.backend_specific("postgresql", "mysql")
     def test_external_session_transaction(self):
@@ -1838,14 +1857,14 @@ class LiveFacadeTest(db_test_base._DbTestCase):
             session.begin()
             session.add(self.User(name="u4"))
 
-        session = self.sessionmaker(autocommit=True)
-
+        session = self.sessionmaker(autocommit=False)
         # inner transaction + second part of "outer" transaction were committed
-        self.assertEqual(
-            [("u2",), ("u3",), ("u4", )],
-            session.query(
-                self.User.name).order_by(self.User.name).all()
-        )
+        with session.begin():
+            self.assertEqual(
+                [("u2",), ("u3",), ("u4", )],
+                session.query(
+                    self.User.name).order_by(self.User.name).all()
+            )
 
     def test_savepoint_transaction_decorator(self):
         context = oslo_context.RequestContext()
@@ -1878,14 +1897,14 @@ class LiveFacadeTest(db_test_base._DbTestCase):
 
         go1(context)
 
-        session = self.sessionmaker(autocommit=True)
-
+        session = self.sessionmaker(autocommit=False)
         # inner transaction + second part of "outer" transaction were committed
-        self.assertEqual(
-            [("u1",), ("u3",), ("u4", )],
-            session.query(
-                self.User.name).order_by(self.User.name).all()
-        )
+        with session.begin():
+            self.assertEqual(
+                [("u1",), ("u3",), ("u4", )],
+                session.query(
+                    self.User.name).order_by(self.User.name).all()
+            )
 
     def test_savepoint_transaction(self):
         context = oslo_context.RequestContext()
@@ -1906,14 +1925,14 @@ class LiveFacadeTest(db_test_base._DbTestCase):
 
             session.add(self.User(name="u4"))
 
-        session = self.sessionmaker(autocommit=True)
-
+        session = self.sessionmaker(autocommit=False)
         # inner transaction + second part of "outer" transaction were committed
-        self.assertEqual(
-            [("u1",), ("u3",), ("u4", )],
-            session.query(
-                self.User.name).order_by(self.User.name).all()
-        )
+        with session.begin():
+            self.assertEqual(
+                [("u1",), ("u3",), ("u4", )],
+                session.query(
+                    self.User.name).order_by(self.User.name).all()
+            )
 
     @db_test_base.backend_specific("postgresql", "mysql")
     def test_external_session_transaction_decorator(self):
@@ -1954,14 +1973,14 @@ class LiveFacadeTest(db_test_base._DbTestCase):
 
         go1(context)
 
-        session = self.sessionmaker(autocommit=True)
-
+        session = self.sessionmaker(autocommit=False)
         # inner transaction + second part of "outer" transaction were committed
-        self.assertEqual(
-            [("u2",), ("u3",), ("u4", )],
-            session.query(
-                self.User.name).order_by(self.User.name).all()
-        )
+        with session.begin():
+            self.assertEqual(
+                [("u2",), ("u3",), ("u4", )],
+                session.query(
+                    self.User.name).order_by(self.User.name).all()
+            )
 
     @db_test_base.backend_specific("postgresql", "mysql")
     def test_external_connection_transaction(self):
@@ -1993,12 +2012,13 @@ class LiveFacadeTest(db_test_base._DbTestCase):
             # add more state on the "outer" transaction
             connection.execute(self.user_table.insert().values(name="u4"))
 
-        session = self.sessionmaker(autocommit=True)
-        self.assertEqual(
-            [("u2",), ("u3",), ("u4", )],
-            session.query(
-                self.User.name).order_by(self.User.name).all()
-        )
+        session = self.sessionmaker(autocommit=False)
+        with session.begin():
+            self.assertEqual(
+                [("u2",), ("u3",), ("u4", )],
+                session.query(
+                    self.User.name).order_by(self.User.name).all()
+            )
 
     @db_test_base.backend_specific("postgresql", "mysql")
     def test_external_writer_in_reader(self):
@@ -2028,12 +2048,13 @@ class LiveFacadeTest(db_test_base._DbTestCase):
             user = session.query(self.User).first()
             self.assertEqual("u1_commit", user.name)
 
-        session = self.sessionmaker(autocommit=True)
-        self.assertEqual(
-            [("u1_commit",)],
-            session.query(
-                self.User.name).order_by(self.User.name).all()
-        )
+        session = self.sessionmaker(autocommit=False)
+        with session.begin():
+            self.assertEqual(
+                [("u1_commit",)],
+                session.query(
+                    self.User.name).order_by(self.User.name).all()
+            )
 
     def test_replace_scope(self):
         # "timeout" is an argument accepted by
